@@ -16,12 +16,14 @@ class Repository:
     def __init__(self, config: Config) -> None:
         self.config = config
 
+        is_debug = True if self.config.get(section='COMMANDS', key='debug') == 'True' else False
+
         username = self.config.get(section='DATABASE', key='username')
         password = self.config.get(section='DATABASE', key='password')
         host = self.config.get(section='DATABASE', key='host')
         port = self.config.get(section='DATABASE', key='port')
         database = self.config.get(section='DATABASE', key='database')
-        self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}', echo=False) # , isolation_level='READ UNCOMMITTED')
+        self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}', echo=is_debug) # , isolation_level='READ UNCOMMITTED')
         Session = sessionmaker(bind=self.engine)
         self.session = scoped_session(Session)
   
